==> manta_manim_theme-0.4.1.tar.gz: manta_manim_theme-0.4.1/manta/color_theme/catppucin/catppuccin_frappe.py <==
from manta.color_theme.catppucin.catppuccin_theme_ABC import CatppuccinThemeABC


class CatppuccinFrappeTheme(CatppuccinThemeABC):

    # ThemeABC
    background_color: str = "#303446"
    background_color_bright: str = "#737994"

    surface_color: str = "#414559"
    outline_color: str = "#737994"

    font_color: str = "#c6d0f5"
    font_color_secondary: str = "b5bfe2"

    black: str = "#51576d"
    black_bright: str = "#51576d"

    red: str = "#ff5e78"
    red_bright: str = "#ff5e78"

    green: str = "#a6d189"
    green_bright: str = "#a6d189"

    yellow: str = "#e5c890"
    yellow_bright: str = "#e5c890"

    blue: str = "#5d9cec"
    blue_bright: str = "#5d9cec"

    magenta: str = "#f4b8e4"
    magenta_bright: str = "#f4b8e4"

    cyan: str = "#81c8be"
    cyan_bright: str = "#81c8be"

    white: str = "#a5adce"
    white_bright: str = "#a5adce"

    # CatppuccinThemeABC
    rosewater: str = "#f2d5cf"
    flamingo: str = "#eebebe"
    pink: str = "#f4b8e4"
    mauve: str = "#ca9ee6"
    maroon: str = "#ea999c"
    peach: str = "#ef9f76"
    teal: str = "#81c8be"
    sky: str = "#99d1db"
    sapphire: str = "#85c1dc"
    lavender: str = "#babbf1"
    text: str = "#c6d0f5"
    subtext1: str = "#b5bfe2"
    subtext0: str = "#a5adce"
    overlay2: str = "#949cbb"
    overlay1: str = "#838ba7"
    overlay0: str = "#737994"
    surface2: str = "#626880"
    surface1: str = "#51576d"
    surface0: str = "#414559"
    base: str = "#303446"
    mantle: str = "#292c3c"
    crust: str = "#232634"

==> manta_manim_theme-0.6.8.tar.gz: manta_manim_theme-0.6.8/manta/color_theme/catppucin/catppuccin_frappe.py <==
from manta.color_theme.catppucin.catppuccin_theme_ABC import CatppuccinThemeABC


class CatppuccinFrappeTheme(CatppuccinThemeABC):
    """
    CatppuccinFrappeTheme defines colors for the Catppuccin Frappe colorscheme as defined in
    https://github.com/catppuccin/catppuccin
    """

    # ThemeABC
    background_color: str = "#303446"
    background_color_bright: str = "#737994"

    surface_color: str = "#414559"
    outline_color: str = "#737994"

    font_color: str = "#c6d0f5"
    font_color_secondary: str = "#b5bfe2"

    black: str = "#51576d"
    black_bright: str = "#51576d"

    red: str = "#ff5e78"
    red_bright: str = "#ff5e78"

    green: str = "#a6d189"
    green_bright: str = "#a6d189"

    yellow: str = "#e5c890"
    yellow_bright: str = "#e5c890"

    blue: str = "#5d9cec"
    blue_bright: str = "#5d9cec"

    magenta: str = "#f4b8e4"
    magenta_bright: str = "#f4b8e4"

    cyan: str = "#81c8be"
    cyan_bright: str = "#81c8be"

    white: str = "#a5adce"
    white_bright: str = "#a5adce"

    # CatppuccinThemeABC
    rosewater: str = "#f2d5cf"
    flamingo: str = "#eebebe"
    pink: str = "#f4b8e4"
    mauve: str = "#ca9ee6"
    maroon: str = "#ea999c"
    peach: str = "#ef9f76"
    teal: str = "#81c8be"
    sky: str = "#99d1db"
    sapphire: str = "#85c1dc"
    lavender: str = "#babbf1"
    text: str = "#c6d0f5"
    subtext1: str = "#b5bfe2"
    subtext0: str = "#a5adce"
    overlay2: str = "#949cbb"
    overlay1: str = "#838ba7"
    overlay0: str = "#737994"
    surface2: str = "#626880"
    surface1: str = "#51576d"
    surface0: str = "#414559"
    base: str = "#303446"
    mantle: str = "#292c3c"
    crust: str = "#232634"
